..
  NOTE: This RST file was generated by `make examples`.
  Do not edit it directly.
  See docs/source/examples/example_doc_generator.py

Chained Widget Alias Example
===============================================================================

An example of using chained Enaml aliases.

.. TIP:: To see this example in action, download it from
 :download:`chained_widget_alias <../../../examples/aliases/chained_widget_alias.enaml>`
 and run::

   $ enaml-run chained_widget_alias.enaml


Screenshot
-------------------------------------------------------------------------------

.. image:: images/ex_chained_widget_alias.png

Example Enaml Code
-------------------------------------------------------------------------------
.. literalinclude:: ../../../examples/aliases/chained_widget_alias.enaml
    :language: enaml
